@@ -2,7 +2,7 @@
 __author__ = "Laurent P. René de Cotret"
 __email__ = "laurent.renedecotret@mail.mcgill.ca"
 __license__ = "MIT"
-__version__ = "2.0.4"
+__version__ = "2.0.5"
 
 from .affine import (
     affine_map,
@@ -62,7 +62,14 @@ from .io import diffread, diffshow, dmread, imibread, mibheader, mibread
 from .patterson import patterson
 from .plot_utils import rgb_sweep, spectrum_colors, spectrum_cmap, indices_to_text
 from .potential_map import potential_map, potential_synthesis
-from .simulation import affe, electrostatic, pelectrostatic, powdersim, structure_factor
+from .simulation import (
+    affe,
+    electrostatic,
+    pelectrostatic,
+    powdersim,
+    structure_factor,
+    kinematicsim,
+)
 from .thin_films import film_optical_coefficients
 from .time_series import (
     biexponential,
@@ -78,5 +85,6 @@ from .time_series import (
     RectSelection,
     DiskSelection,
     RingSelection,
+    RingArcSelection,
 )
 from .voigt import gaussian, lorentzian, pseudo_voigt
