@@ -5,11 +5,13 @@ Polycrystalline diffraction pattern simulation
 """
 import numpy as np
 
+from crystals.affine import change_basis_mesh
+
 from ..voigt import pseudo_voigt
-from .structure_factors import bounded_reflections, structure_factor
+from .structure_factors import structure_factor
 
 
-def powdersim(crystal, q, fwhm_g = 0.03, fwhm_l = 0.06, **kwargs):
+def powdersim(crystal, q, fwhm_g=0.03, fwhm_l=0.06, **kwargs):
     """
     Simulates polycrystalline diffraction pattern.
 
@@ -28,12 +30,13 @@ def powdersim(crystal, q, fwhm_g = 0.03, fwhm_l = 0.06, **kwargs):
     pattern : `~numpy.ndarray`, shape (N,)
         Diffraction pattern
     """
-    h, k, l = bounded_reflections(crystal, nG = q.max())
-    Gx, Gy, Gz = crystal.scattering_vector(h, k, l)
-    qs = np.sqrt(Gx**2 + Gy**2 + Gz**2)
-    intensities = np.absolute(structure_factor(crystal, h, k, l))**2
-
-    psf = pseudo_voigt(q, center = np.mean(q), fwhm_g = fwhm_g, fwhm_l = fwhm_l)
+    refls = np.vstack(tuple(crystal.bounded_reflections(q.max())))
+    h, k, l = np.hsplit(refls, 3)
+    Gx, Gy, Gz = change_basis_mesh(
+        h, k, l, basis1=crystal.reciprocal_vectors, basis2=np.eye(3)
+    )
+    qs = np.sqrt(Gx ** 2 + Gy ** 2 + Gz ** 2)
+    intensities = np.absolute(structure_factor(crystal, h, k, l)) ** 2
 
     pattern = np.zeros_like(q)
     for qi, i in zip(qs, intensities):
